tlslite.constants.Fault

Package tlslite :: Module constants :: Class Fault |
[hide private]
[frames] | no frames]

# Class Fault

source code

Class Variables | [hide private]
| badA = `103`
| badB = `201`
| badFinished = `300`
| badMAC = `301`
| badPadding = `302`
| badPassword = `102`
| badPremasterPadding = `501`
| badUsername = `101`
| badVerifyMessage = `601`
| clientCertFaults = ``[`601`]``
| clientNoAuthFaults = ``[`501`,` 502`]``
| clientSrpFaults = ``[`101`,` 102`,` 103`]``
| faultAlerts = ``{`101`:` `(`115`,` 20`)``,` 102`:` `(`20`)``,` 103`:` `(`47`)``,` 300`:` `(`51`)``...``
| faultNames = ``{`101`:` `'``bad username``'``,` 102`:` `'``bad password``'``,` 103`:` `'``...``
| genericFaults = ``[`300`,` 301`,` 302`]``
| serverFaults = ``[`201`]``
| shortPremasterSecret = `502`

Class Variable Details | [hide private]

  ### faultAlerts Value:
      {101: (115, 20),
       102: (20),
       103: (47),
       300: (51),
       301: (20),
       302: (20),
       501: (20),
       502: (20),
      ...

  ### faultNames Value:
      {101: 'bad username',
       102: 'bad password',
       103: 'bad A',
       300: 'bad finished message',
       301: 'bad MAC',
       302: 'bad padding',
       501: 'bad premaster padding',
       502: 'short premaster secret',
      ...